pub struct DiffResult {
pub want: Vec<String>,
pub delete_extraneous: Vec<String>,
}Fields
want: Vec<String>List of forward-slash relative paths the agent needs the client to upload
delete_extraneous: Vec<String>List of forward-slash relative paths present remotely that should be deleted